Package: rtpcr
Type: Package
Title: qPCR Data Analysis
Version: 2.1.8
Authors@R: c(person("Ghader", "Mirzaghaderi", role=c("aut", "cre", "cph"), email = "mirzaghaderi@gmail.com"))
Description: Tools for qPCR data analysis using Delta Ct and Delta Delta Ct methods, including t-test, Wilcoxon-test, ANOVA models, and publication-ready visualizations. The package supports multiple target, and multiple reference genes, and uses a calculation framework adopted from Ganger et al. (2017) <doi:10.1186/s12859-017-1949-5> and Taylor et al. (2019) <doi:10.1016/j.tibtech.2018.12.002>, covering both the Livak and Pfaffl methods.
URL: https://mirzaghaderi.github.io/rtpcr/,
        https://github.com/mirzaghaderi/rtpcr
License: GPL-3
Imports: multcomp, ggplot2, lme4, lmerTest, purrr, reshape2, tidyr,
        dplyr, grid, emmeans, lifecycle
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-18 19:05:58 UTC; GM
Author: Ghader Mirzaghaderi [aut, cre, cph]
Depends: R (>= 3.5.0)
Suggests: knitr, rmarkdown, multcompView
VignetteBuilder: knitr
LazyData: true
Maintainer: Ghader Mirzaghaderi <mirzaghaderi@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-21 09:20:02 UTC
Built: R 4.6.0; ; 2026-05-25 04:26:52 UTC; unix
