# Generated by roxygen2: do not edit by hand

export(ANOVA_DCt)
export(ANOVA_DDCt)
export(Means_DDCt)
export(TTEST_DDCt)
export(WILCOX_DDCt)
export(compute_wDCt)
export(efficiency)
export(long_to_wide)
export(meanTech)
export(multiplot)
export(plotFactor)
import(dplyr)
import(emmeans)
import(ggplot2)
import(grid)
import(purrr)
import(reshape2)
import(tidyr)
importFrom(stats,setNames)
